==> huaweicloudsdksmn-3.0.52-py2.py3-none-any.whl: huaweicloudsdksmn/v2/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdksmn.v2.model.add_subscription_request import AddSubscriptionRequest
from huaweicloudsdksmn.v2.model.add_subscription_request_body import AddSubscriptionRequestBody
from huaweicloudsdksmn.v2.model.add_subscription_response import AddSubscriptionResponse
from huaweicloudsdksmn.v2.model.application_endpoint import ApplicationEndpoint
from huaweicloudsdksmn.v2.model.application_item import ApplicationItem
from huaweicloudsdksmn.v2.model.batch_create_or_delete_resource_tags_request import BatchCreateOrDeleteResourceTagsRequest
from huaweicloudsdksmn.v2.model.batch_create_or_delete_resource_tags_request_body import BatchCreateOrDeleteResourceTagsRequestBody
from huaweicloudsdksmn.v2.model.batch_create_or_delete_resource_tags_response import BatchCreateOrDeleteResourceTagsResponse
from huaweicloudsdksmn.v2.model.cancel_subscription_request import CancelSubscriptionRequest
from huaweicloudsdksmn.v2.model.cancel_subscription_response import CancelSubscriptionResponse
from huaweicloudsdksmn.v2.model.create_application_endpoint_request import CreateApplicationEndpointRequest
from huaweicloudsdksmn.v2.model.create_application_endpoint_request_body import CreateApplicationEndpointRequestBody
from huaweicloudsdksmn.v2.model.create_application_endpoint_response import CreateApplicationEndpointResponse
from huaweicloudsdksmn.v2.model.create_application_request import CreateApplicationRequest
from huaweicloudsdksmn.v2.model.create_application_request_body import CreateApplicationRequestBody
from huaweicloudsdksmn.v2.model.create_application_response import CreateApplicationResponse
from huaweicloudsdksmn.v2.model.create_message_template_request import CreateMessageTemplateRequest
from huaweicloudsdksmn.v2.model.create_message_template_request_body import CreateMessageTemplateRequestBody
from huaweicloudsdksmn.v2.model.create_message_template_response import CreateMessageTemplateResponse
from huaweicloudsdksmn.v2.model.create_resource_tag_request import CreateResourceTagRequest
from huaweicloudsdksmn.v2.model.create_resource_tag_request_body import CreateResourceTagRequestBody
from huaweicloudsdksmn.v2.model.create_resource_tag_request_body_tag import CreateResourceTagRequestBodyTag
from huaweicloudsdksmn.v2.model.create_resource_tag_response import CreateResourceTagResponse
from huaweicloudsdksmn.v2.model.create_topic_request import CreateTopicRequest
from huaweicloudsdksmn.v2.model.create_topic_request_body import CreateTopicRequestBody
from huaweicloudsdksmn.v2.model.create_topic_response import CreateTopicResponse
from huaweicloudsdksmn.v2.model.delete_application_endpoint_request import DeleteApplicationEndpointRequest
from huaweicloudsdksmn.v2.model.delete_application_endpoint_response import DeleteApplicationEndpointResponse
from huaweicloudsdksmn.v2.model.delete_application_request import DeleteApplicationRequest
from huaweicloudsdksmn.v2.model.delete_application_response import DeleteApplicationResponse
from huaweicloudsdksmn.v2.model.delete_message_template_request import DeleteMessageTemplateRequest
from huaweicloudsdksmn.v2.model.delete_message_template_response import DeleteMessageTemplateResponse
from huaweicloudsdksmn.v2.model.delete_resource_tag_request import DeleteResourceTagRequest
from huaweicloudsdksmn.v2.model.delete_resource_tag_response import DeleteResourceTagResponse
from huaweicloudsdksmn.v2.model.delete_topic_attribute_by_name_request import DeleteTopicAttributeByNameRequest
from huaweicloudsdksmn.v2.model.delete_topic_attribute_by_name_response import DeleteTopicAttributeByNameResponse
from huaweicloudsdksmn.v2.model.delete_topic_attributes_request import DeleteTopicAttributesRequest
from huaweicloudsdksmn.v2.model.delete_topic_attributes_response import DeleteTopicAttributesResponse
from huaweicloudsdksmn.v2.model.delete_topic_request import DeleteTopicRequest
from huaweicloudsdksmn.v2.model.delete_topic_response import DeleteTopicResponse
from huaweicloudsdksmn.v2.model.links_item import LinksItem
from huaweicloudsdksmn.v2.model.list_application_attributes_request import ListApplicationAttributesRequest
from huaweicloudsdksmn.v2.model.list_application_attributes_response import ListApplicationAttributesResponse
from huaweicloudsdksmn.v2.model.list_application_attributes_response_body_attributes import ListApplicationAttributesResponseBodyAttributes
from huaweicloudsdksmn.v2.model.list_application_endpoint_attributes_request import ListApplicationEndpointAttributesRequest
from huaweicloudsdksmn.v2.model.list_application_endpoint_attributes_response import ListApplicationEndpointAttributesResponse
from huaweicloudsdksmn.v2.model.list_application_endpoint_attributes_response_body_attributes import ListApplicationEndpointAttributesResponseBodyAttributes
from huaweicloudsdksmn.v2.model.list_application_endpoints_request import ListApplicationEndpointsRequest
from huaweicloudsdksmn.v2.model.list_application_endpoints_response import ListApplicationEndpointsResponse
from huaweicloudsdksmn.v2.model.list_applications_request import ListApplicationsRequest
from huaweicloudsdksmn.v2.model.list_applications_response import ListApplicationsResponse
from huaweicloudsdksmn.v2.model.list_instance_request_body import ListInstanceRequestBody
from huaweicloudsdksmn.v2.model.list_message_template_details_request import ListMessageTemplateDetailsRequest
from huaweicloudsdksmn.v2.model.list_message_template_details_response import ListMessageTemplateDetailsResponse
from huaweicloudsdksmn.v2.model.list_message_templates_request import ListMessageTemplatesRequest
from huaweicloudsdksmn.v2.model.list_message_templates_response import ListMessageTemplatesResponse
from huaweicloudsdksmn.v2.model.list_project_tags_request import ListProjectTagsRequest
from huaweicloudsdksmn.v2.model.list_project_tags_response import ListProjectTagsResponse
from huaweicloudsdksmn.v2.model.list_resource_instances_request import ListResourceInstancesRequest
from huaweicloudsdksmn.v2.model.list_resource_instances_response import ListResourceInstancesResponse
from huaweicloudsdksmn.v2.model.list_resource_tags_request import ListResourceTagsRequest
from huaweicloudsdksmn.v2.model.list_resource_tags_response import ListResourceTagsResponse
from huaweicloudsdksmn.v2.model.list_subscriptions_by_topic_request import ListSubscriptionsByTopicRequest
from huaweicloudsdksmn.v2.model.list_subscriptions_by_topic_response import ListSubscriptionsByTopicResponse
from huaweicloudsdksmn.v2.model.list_subscriptions_item import ListSubscriptionsItem
from huaweicloudsdksmn.v2.model.list_subscriptions_request import ListSubscriptionsRequest
from huaweicloudsdksmn.v2.model.list_subscriptions_response import ListSubscriptionsResponse
from huaweicloudsdksmn.v2.model.list_topic_attributes_request import ListTopicAttributesRequest
from huaweicloudsdksmn.v2.model.list_topic_attributes_response import ListTopicAttributesResponse
from huaweicloudsdksmn.v2.model.list_topic_details_request import ListTopicDetailsRequest
from huaweicloudsdksmn.v2.model.list_topic_details_response import ListTopicDetailsResponse
from huaweicloudsdksmn.v2.model.list_topics_item import ListTopicsItem
from huaweicloudsdksmn.v2.model.list_topics_request import ListTopicsRequest
from huaweicloudsdksmn.v2.model.list_topics_response import ListTopicsResponse
from huaweicloudsdksmn.v2.model.list_version_request import ListVersionRequest
from huaweicloudsdksmn.v2.model.list_version_response import ListVersionResponse
from huaweicloudsdksmn.v2.model.list_versions_request import ListVersionsRequest
from huaweicloudsdksmn.v2.model.list_versions_response import ListVersionsResponse
from huaweicloudsdksmn.v2.model.message_template import MessageTemplate
from huaweicloudsdksmn.v2.model.publish_app_message_request import PublishAppMessageRequest
from huaweicloudsdksmn.v2.model.publish_app_message_request_body import PublishAppMessageRequestBody
from huaweicloudsdksmn.v2.model.publish_app_message_response import PublishAppMessageResponse
from huaweicloudsdksmn.v2.model.publish_message_request import PublishMessageRequest
from huaweicloudsdksmn.v2.model.publish_message_request_body import PublishMessageRequestBody
from huaweicloudsdksmn.v2.model.publish_message_response import PublishMessageResponse
from huaweicloudsdksmn.v2.model.resource_detail import ResourceDetail
from huaweicloudsdksmn.v2.model.resource_tag import ResourceTag
from huaweicloudsdksmn.v2.model.resource_tags import ResourceTags
from huaweicloudsdksmn.v2.model.statement import Statement
from huaweicloudsdksmn.v2.model.tag_match import TagMatch
from huaweicloudsdksmn.v2.model.tag_resource import TagResource
from huaweicloudsdksmn.v2.model.topic_attribute import TopicAttribute
from huaweicloudsdksmn.v2.model.update_application_endpoint_request import UpdateApplicationEndpointRequest
from huaweicloudsdksmn.v2.model.update_application_endpoint_request_body import UpdateApplicationEndpointRequestBody
from huaweicloudsdksmn.v2.model.update_application_endpoint_response import UpdateApplicationEndpointResponse
from huaweicloudsdksmn.v2.model.update_application_request import UpdateApplicationRequest
from huaweicloudsdksmn.v2.model.update_application_request_body import UpdateApplicationRequestBody
from huaweicloudsdksmn.v2.model.update_application_response import UpdateApplicationResponse
from huaweicloudsdksmn.v2.model.update_message_template_request import UpdateMessageTemplateRequest
from huaweicloudsdksmn.v2.model.update_message_template_request_body import UpdateMessageTemplateRequestBody
from huaweicloudsdksmn.v2.model.update_message_template_response import UpdateMessageTemplateResponse
from huaweicloudsdksmn.v2.model.update_topic_attribute_request import UpdateTopicAttributeRequest
from huaweicloudsdksmn.v2.model.update_topic_attribute_request_body import UpdateTopicAttributeRequestBody
from huaweicloudsdksmn.v2.model.update_topic_attribute_response import UpdateTopicAttributeResponse
from huaweicloudsdksmn.v2.model.update_topic_request import UpdateTopicRequest
from huaweicloudsdksmn.v2.model.update_topic_request_body import UpdateTopicRequestBody
from huaweicloudsdksmn.v2.model.update_topic_response import UpdateTopicResponse
from huaweicloudsdksmn.v2.model.version_item import VersionItem

==> huaweicloudsdksmn-3.1.65-py2.py3-none-any.whl: huaweicloudsdksmn/v2/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdksmn.v2.model.access_policy import AccessPolicy
from huaweicloudsdksmn.v2.model.add_subscription_request import AddSubscriptionRequest
from huaweicloudsdksmn.v2.model.add_subscription_request_body import AddSubscriptionRequestBody
from huaweicloudsdksmn.v2.model.add_subscription_response import AddSubscriptionResponse
from huaweicloudsdksmn.v2.model.application_endpoint import ApplicationEndpoint
from huaweicloudsdksmn.v2.model.application_item import ApplicationItem
from huaweicloudsdksmn.v2.model.batch_create_or_delete_resource_tags_request import BatchCreateOrDeleteResourceTagsRequest
from huaweicloudsdksmn.v2.model.batch_create_or_delete_resource_tags_request_body import BatchCreateOrDeleteResourceTagsRequestBody
from huaweicloudsdksmn.v2.model.batch_create_or_delete_resource_tags_response import BatchCreateOrDeleteResourceTagsResponse
from huaweicloudsdksmn.v2.model.cancel_subscription_request import CancelSubscriptionRequest
from huaweicloudsdksmn.v2.model.cancel_subscription_response import CancelSubscriptionResponse
from huaweicloudsdksmn.v2.model.create_application_endpoint_request import CreateApplicationEndpointRequest
from huaweicloudsdksmn.v2.model.create_application_endpoint_request_body import CreateApplicationEndpointRequestBody
from huaweicloudsdksmn.v2.model.create_application_endpoint_response import CreateApplicationEndpointResponse
from huaweicloudsdksmn.v2.model.create_application_request import CreateApplicationRequest
from huaweicloudsdksmn.v2.model.create_application_request_body import CreateApplicationRequestBody
from huaweicloudsdksmn.v2.model.create_application_response import CreateApplicationResponse
from huaweicloudsdksmn.v2.model.create_logtank_request import CreateLogtankRequest
from huaweicloudsdksmn.v2.model.create_logtank_request_body import CreateLogtankRequestBody
from huaweicloudsdksmn.v2.model.create_logtank_response import CreateLogtankResponse
from huaweicloudsdksmn.v2.model.create_message_template_request import CreateMessageTemplateRequest
from huaweicloudsdksmn.v2.model.create_message_template_request_body import CreateMessageTemplateRequestBody
from huaweicloudsdksmn.v2.model.create_message_template_response import CreateMessageTemplateResponse
from huaweicloudsdksmn.v2.model.create_resource_tag_request import CreateResourceTagRequest
from huaweicloudsdksmn.v2.model.create_resource_tag_request_body import CreateResourceTagRequestBody
from huaweicloudsdksmn.v2.model.create_resource_tag_response import CreateResourceTagResponse
from huaweicloudsdksmn.v2.model.create_topic_request import CreateTopicRequest
from huaweicloudsdksmn.v2.model.create_topic_request_body import CreateTopicRequestBody
from huaweicloudsdksmn.v2.model.create_topic_response import CreateTopicResponse
from huaweicloudsdksmn.v2.model.delete_application_endpoint_request import DeleteApplicationEndpointRequest
from huaweicloudsdksmn.v2.model.delete_application_endpoint_response import DeleteApplicationEndpointResponse
from huaweicloudsdksmn.v2.model.delete_application_request import DeleteApplicationRequest
from huaweicloudsdksmn.v2.model.delete_application_response import DeleteApplicationResponse
from huaweicloudsdksmn.v2.model.delete_logtank_request import DeleteLogtankRequest
from huaweicloudsdksmn.v2.model.delete_logtank_response import DeleteLogtankResponse
from huaweicloudsdksmn.v2.model.delete_message_template_request import DeleteMessageTemplateRequest
from huaweicloudsdksmn.v2.model.delete_message_template_response import DeleteMessageTemplateResponse
from huaweicloudsdksmn.v2.model.delete_resource_tag_request import DeleteResourceTagRequest
from huaweicloudsdksmn.v2.model.delete_resource_tag_response import DeleteResourceTagResponse
from huaweicloudsdksmn.v2.model.delete_topic_attribute_by_name_request import DeleteTopicAttributeByNameRequest
from huaweicloudsdksmn.v2.model.delete_topic_attribute_by_name_response import DeleteTopicAttributeByNameResponse
from huaweicloudsdksmn.v2.model.delete_topic_attributes_request import DeleteTopicAttributesRequest
from huaweicloudsdksmn.v2.model.delete_topic_attributes_response import DeleteTopicAttributesResponse
from huaweicloudsdksmn.v2.model.delete_topic_request import DeleteTopicRequest
from huaweicloudsdksmn.v2.model.delete_topic_response import DeleteTopicResponse
from huaweicloudsdksmn.v2.model.links_item import LinksItem
from huaweicloudsdksmn.v2.model.list_application_attributes_request import ListApplicationAttributesRequest
from huaweicloudsdksmn.v2.model.list_application_attributes_response import ListApplicationAttributesResponse
from huaweicloudsdksmn.v2.model.list_application_attributes_response_body_attributes import ListApplicationAttributesResponseBodyAttributes
from huaweicloudsdksmn.v2.model.list_application_endpoint_attributes_request import ListApplicationEndpointAttributesRequest
from huaweicloudsdksmn.v2.model.list_application_endpoint_attributes_response import ListApplicationEndpointAttributesResponse
from huaweicloudsdksmn.v2.model.list_application_endpoint_attributes_response_body_attributes import ListApplicationEndpointAttributesResponseBodyAttributes
from huaweicloudsdksmn.v2.model.list_application_endpoints_request import ListApplicationEndpointsRequest
from huaweicloudsdksmn.v2.model.list_application_endpoints_response import ListApplicationEndpointsResponse
from huaweicloudsdksmn.v2.model.list_applications_request import ListApplicationsRequest
from huaweicloudsdksmn.v2.model.list_applications_response import ListApplicationsResponse
from huaweicloudsdksmn.v2.model.list_instance_request_body import ListInstanceRequestBody
from huaweicloudsdksmn.v2.model.list_logtank_request import ListLogtankRequest
from huaweicloudsdksmn.v2.model.list_logtank_response import ListLogtankResponse
from huaweicloudsdksmn.v2.model.list_message_template_details_request import ListMessageTemplateDetailsRequest
from huaweicloudsdksmn.v2.model.list_message_template_details_response import ListMessageTemplateDetailsResponse
from huaweicloudsdksmn.v2.model.list_message_templates_request import ListMessageTemplatesRequest
from huaweicloudsdksmn.v2.model.list_message_templates_response import ListMessageTemplatesResponse
from huaweicloudsdksmn.v2.model.list_project_tags_request import ListProjectTagsRequest
from huaweicloudsdksmn.v2.model.list_project_tags_response import ListProjectTagsResponse
from huaweicloudsdksmn.v2.model.list_resource_instances_request import ListResourceInstancesRequest
from huaweicloudsdksmn.v2.model.list_resource_instances_response import ListResourceInstancesResponse
from huaweicloudsdksmn.v2.model.list_resource_tags_request import ListResourceTagsRequest
from huaweicloudsdksmn.v2.model.list_resource_tags_response import ListResourceTagsResponse
from huaweicloudsdksmn.v2.model.list_subscriptions_by_topic_request import ListSubscriptionsByTopicRequest
from huaweicloudsdksmn.v2.model.list_subscriptions_by_topic_response import ListSubscriptionsByTopicResponse
from huaweicloudsdksmn.v2.model.list_subscriptions_item import ListSubscriptionsItem
from huaweicloudsdksmn.v2.model.list_subscriptions_request import ListSubscriptionsRequest
from huaweicloudsdksmn.v2.model.list_subscriptions_response import ListSubscriptionsResponse
from huaweicloudsdksmn.v2.model.list_topic_attributes_request import ListTopicAttributesRequest
from huaweicloudsdksmn.v2.model.list_topic_attributes_response import ListTopicAttributesResponse
from huaweicloudsdksmn.v2.model.list_topic_details_request import ListTopicDetailsRequest
from huaweicloudsdksmn.v2.model.list_topic_details_response import ListTopicDetailsResponse
from huaweicloudsdksmn.v2.model.list_topics_item import ListTopicsItem
from huaweicloudsdksmn.v2.model.list_topics_request import ListTopicsRequest
from huaweicloudsdksmn.v2.model.list_topics_response import ListTopicsResponse
from huaweicloudsdksmn.v2.model.list_version_request import ListVersionRequest
from huaweicloudsdksmn.v2.model.list_version_response import ListVersionResponse
from huaweicloudsdksmn.v2.model.list_versions_request import ListVersionsRequest
from huaweicloudsdksmn.v2.model.list_versions_response import ListVersionsResponse
from huaweicloudsdksmn.v2.model.logtank_item import LogtankItem
from huaweicloudsdksmn.v2.model.message_template import MessageTemplate
from huaweicloudsdksmn.v2.model.publish_app_message_request import PublishAppMessageRequest
from huaweicloudsdksmn.v2.model.publish_app_message_request_body import PublishAppMessageRequestBody
from huaweicloudsdksmn.v2.model.publish_app_message_response import PublishAppMessageResponse
from huaweicloudsdksmn.v2.model.publish_message_request import PublishMessageRequest
from huaweicloudsdksmn.v2.model.publish_message_request_body import PublishMessageRequestBody
from huaweicloudsdksmn.v2.model.publish_message_response import PublishMessageResponse
from huaweicloudsdksmn.v2.model.resource_detail import ResourceDetail
from huaweicloudsdksmn.v2.model.resource_tag import ResourceTag
from huaweicloudsdksmn.v2.model.resource_tags import ResourceTags
from huaweicloudsdksmn.v2.model.statement import Statement
from huaweicloudsdksmn.v2.model.subscription_extension import SubscriptionExtension
from huaweicloudsdksmn.v2.model.tag_match import TagMatch
from huaweicloudsdksmn.v2.model.tag_resource import TagResource
from huaweicloudsdksmn.v2.model.topic_attribute import TopicAttribute
from huaweicloudsdksmn.v2.model.update_application_endpoint_request import UpdateApplicationEndpointRequest
from huaweicloudsdksmn.v2.model.update_application_endpoint_request_body import UpdateApplicationEndpointRequestBody
from huaweicloudsdksmn.v2.model.update_application_endpoint_response import UpdateApplicationEndpointResponse
from huaweicloudsdksmn.v2.model.update_application_request import UpdateApplicationRequest
from huaweicloudsdksmn.v2.model.update_application_request_body import UpdateApplicationRequestBody
from huaweicloudsdksmn.v2.model.update_application_response import UpdateApplicationResponse
from huaweicloudsdksmn.v2.model.update_logtank_request import UpdateLogtankRequest
from huaweicloudsdksmn.v2.model.update_logtank_request_body import UpdateLogtankRequestBody
from huaweicloudsdksmn.v2.model.update_logtank_response import UpdateLogtankResponse
from huaweicloudsdksmn.v2.model.update_message_template_request import UpdateMessageTemplateRequest
from huaweicloudsdksmn.v2.model.update_message_template_request_body import UpdateMessageTemplateRequestBody
from huaweicloudsdksmn.v2.model.update_message_template_response import UpdateMessageTemplateResponse
from huaweicloudsdksmn.v2.model.update_subscription_request import UpdateSubscriptionRequest
from huaweicloudsdksmn.v2.model.update_subscription_request_body import UpdateSubscriptionRequestBody
from huaweicloudsdksmn.v2.model.update_subscription_response import UpdateSubscriptionResponse
from huaweicloudsdksmn.v2.model.update_topic_attribute_request import UpdateTopicAttributeRequest
from huaweicloudsdksmn.v2.model.update_topic_attribute_request_body import UpdateTopicAttributeRequestBody
from huaweicloudsdksmn.v2.model.update_topic_attribute_response import UpdateTopicAttributeResponse
from huaweicloudsdksmn.v2.model.update_topic_request import UpdateTopicRequest
from huaweicloudsdksmn.v2.model.update_topic_request_body import UpdateTopicRequestBody
from huaweicloudsdksmn.v2.model.update_topic_response import UpdateTopicResponse
from huaweicloudsdksmn.v2.model.version_item import VersionItem
